#/bin/sh

# COMMANDS

CP="/bin/cp"
CHKCONFIG="/sbin/chkconfig"
DATE="/bin/date"
ECHO="/bin/echo"
ID="/usr/bin/id"
PPWD="/bin/pwd"

# ENVIRONMENTAL VARIABLES

LANG=C
XMLFILE="parameterinfo.xml"

# SUB ROUTINE

Write_XML_bool()
{
	$ECHO "<parameter>">> ${OUTPUTDIR}/${XMLFILE}
	$ECHO "<key>$1</key>">> ${OUTPUTDIR}/${XMLFILE}
	$ECHO "<value>TRUE</value>">> ${OUTPUTDIR}/${XMLFILE}
	$ECHO "</parameter>">> ${OUTPUTDIR}/${XMLFILE}

	return 0
}

# PRE CHECK

if [ `$ID -u` -ne 0 ] ; then
	$ECHO "ERROR0001: need to be root user" 1>&2
	exit 1
fi

if [ $# -ne 2 -o "x$1" != "x-dir" ] ; then
	$ECHO "ERROR0002: usage: discover.sh -dir <dirname>" 1>&2
	exit 1
fi

if [ ! -d $2 ] ; then
	$ECHO "ERROR0003: dirname $2 not found" 1>&2
	exit 1
fi

# OUTPUT ABSOLUTE DIRECTORY SET

pushd $2 1>/dev/null
OUTPUTDIR=`$PPWD`
popd 1>/dev/null

# MAIN

$ECHO "INFO: Red Hat Enterprise Linux 6.2 discover started `$DATE`"

# CREATE XML HEADER
$ECHO "<?xml version=\"1.0\" encoding=\"UTF-8\"?>
<parameterInfo version=\"1.0\">
<name>Red Hat Enterprise Linux</name>
<parameters>">>${OUTPUTDIR}/${XMLFILE}

if [ $? -ne 0 ] ; then
	$ECHO "ERROR0005 Failed to create XMLFILE" 1>&2
	exit 1
fi

# COPY PARAMETER FILE

$ECHO "IFNO: copy sysctl.conf"
if $CP -p /etc/sysctl.conf $OUTPUTDIR/sysctl.conf ; then
	Write_XML_bool sysctl_conf
else
	$ECHO "ERROR0004: Failed to copy sysctl.conf" 1>&2
fi

$ECHO "INFO: copy grub.conf"
if $CP -p /etc/grub.conf $OUTPUTDIR/grub.conf ; then
	Write_XML_bool grub_conf
else
	$ECHO "ERROR0004: Failed to copy grub.conf" 1>&2
fi

$ECHO "INFO: copy limits.conf"
if $CP -p /etc/security/limits.conf $OUTPUTDIR/limits.conf ; then
	Write_XML_bool limits_conf
else
	$ECHO "ERROR0004: Failed to copy limits.conf" 1>&2
fi

$ECHO "INFO: copy rsyslog.conf"
if $CP -p /etc/rsyslog.conf $OUTPUTDIR/rsyslog.conf ; then
	Write_XML_bool rsyslog_conf
else
	$ECHO "ERROR0004: Failed to copy rsyslog.conf" 1>&2
fi

$ECHO "INFO: copy selinux"
if $CP -p /etc/selinux/config $OUTPUTDIR/config ; then
	Write_XML_bool selinux
else
	$ECHO "ERROR0004: Failed to copy /etc/selinux/confug" 1>&2
fi

$ECHO "INFO: copy fstab"
if $CP -p /etc/fstab $OUTPUTDIR/fstab ; then
	Write_XML_bool fstab
else
	$ECHO "ERROR0004: Failed to copy fstab" 1>&2
fi

$ECHO "INFO: copy hosts"
if $CP -p /etc/hosts $OUTPUTDIR/hosts ; then
	Write_XML_bool hosts
else
	$ECHO "ERROR0004: Failed to copy hosts" 1>&2
fi

$ECHO "INFO: copy ntpd"
if $CP -p /etc/sysconfig/ntpd $OUTPUTDIR/ntpd ; then
	Write_XML_bool ntpd
else
	$ECHO "ERROR0004: Failed to copy ntpd" 1>&2
fi

$ECHO "INFO: copy ntpdate"
if $CP -p /etc/sysconfig/ntpdate $OUTPUTDIR/ntpdate ; then
	Write_XML_bool ntpdate
else
	$ECHO "ERROR0004: Failed to copy ntpdate" 1>&2
fi

$ECHO "INFO: copy snmpd.conf"
if $CP -p /etc/snmp/snmpd.conf $OUTPUTDIR/snmpd.conf ; then
	Write_XML_bool snmpd_conf
else
	$ECHO "ERROR0004: Failed to copy snmpd.conf" 1>&2
fi

$ECHO "INFO: copy services"
if $CP -p /etc/services $OUTPUTDIR/services ; then
	Write_XML_bool services
else
	$ECHO "ERROR0004: Failed to copy services" 1>&2
fi

$ECHO "INFO: copy profile"
if $CP -p /etc/profile $OUTPUTDIR/profile ; then
	Write_XML_bool profile
else
	$ECHO "ERROR0004: Failed to copy profile" 1>&2
fi

$ECHO "INFO: get service status"
if $CHKCONFIG --list > $OUTPUTDIR/chkconfig.txt ; then
	Write_XML_bool chkconfig
else
	$ECHO "ERROR0004: Failed to get service status" 1>&2
fi

# CREATE XML FOOTER

$ECHO "</parameters>">>${OUTPUTDIR}/${XMLFILE}
$ECHO "</parameterInfo>">>${OUTPUTDIR}/${XMLFILE}
if [ $? -ne 0 ] ; then
	$ECHO "ERROR0005: Failed to create $XMLFILE" 1>&2
	exit 1
fi

$ECHO "INFO: Red Hat Enterprise Linux 6.2 discover ended `$DATE`"
exit 0
