#/bin/sh

#commands

CP="/bin/cp"
DATE="/bin/date"
DIRNAME="/usr/bin/dirname"
ECHO="/bin/echo"
ID="/usr/bin/id"
PPWD="/bin/pwd"

# environmental variables

LANG=C
unset sysctl_conf
unset grub_conf
unset limits_conf
unset rsyslog_conf
unset selinux
unset fstab
unset hosts
unset ntpd
unset ntpdate
unset snmpd_conf
unset services
unset profile
RET=0
root_dir_path_guest=

#
# Method that update localhost of hosts.
# args
#  non
# return
#  0 succeeded
#  1 failed
# referred value
#  ${hosts_localhost_update_hostname}       hostname
#  ${hosts_localhost_update_hostname_old}   old hostname
#  ${hosts_localhost_update_domainname}     domainname
#  ${hosts_localhost_update_domainname_old} old domainname
#  ${hosts_localhost_update_ipaddresses}    IP addresses
#
method_update_localhost_of_hosts()
{
# Rename /etc/hosts to /etc/hosts.bak. Make empty /etc/hosts.
if [ -r ${root_dir_path_guest}/etc/hosts ] ; then
	mv -f ${root_dir_path_guest}/etc/hosts ${root_dir_path_guest}/etc/hosts.bak
	touch ${root_dir_path_guest}/etc/hosts
else
	$ECHO "ERROR0005: set hosts localhost update failed. Cannot read ${root_dir_path_guest}/etc/hosts." 1>&2
	exit 1 
fi

# Update, and delete an existing list.
default_IFS=$IFS
IFS=
while read LINE;
do
	if echo ${LINE} | grep -q '^127\.[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}[[:space:]]' ; then
		rest=`echo ${LINE} | sed -e 's/^127.[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}//'`
		loop_back_addre=${LINE%${rest}} 
		localhost_in_hosts=`echo ${rest} | sed -e "s/\t/ /g" | sed -e "s/\s\+/ /g"`
		
		new_localhost_in_hosts=
		update_line=0
		IFS=${default_IFS}
		for token in ${localhost_in_hosts}
		do
			if [ "${hosts_localhost_update_domainname_old}" != "" ] &&
			   [ "${hosts_localhost_update_hostname_old}.${hosts_localhost_update_domainname_old}" = "${token}" ] ; then
				if [ "${hosts_localhost_update_domainname}" != "" ] ; then
					new_localhost_in_hosts="${new_localhost_in_hosts} ${hosts_localhost_update_hostname}.${hosts_localhost_update_domainname}"
				fi
				update_line=1
			elif [ "${hosts_localhost_update_hostname_old}" = "${token}" ] ; then
				new_localhost_in_hosts="${new_localhost_in_hosts} ${hosts_localhost_update_hostname}"
				update_line=1
			else
				new_localhost_in_hosts="${new_localhost_in_hosts} ${token}"
			fi
		done
		IFS=
		
		if [ "${update_line}" -eq 1 ] ; then
			write_line="${loop_back_addre}\t${new_localhost_in_hosts}"
		else
			write_line=${LINE}
		fi
		echo -e ${write_line} >> ${root_dir_path_guest}/etc/hosts 2>&1
	
	elif echo ${LINE} | grep -q '^[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}\.[0-9]\{1,3\}[[:space:]]' ; then
		# not write when  hostname or ailas in a line which equals old hostname
		# write when hostname or alias in a line different from old hostname
		line_no_comment=`echo ${LINE} | sed -e 's/#.*//'`
		
		write_old_line=1
		IFS=${default_IFS}
		for token in ${line_no_comment}
		do
			if [ "${hosts_localhost_update_domainname_old}" != "" ] &&
			   [ "${token}" = "${hosts_localhost_update_hostname_old}.${hosts_localhost_update_domainname_old}" ] ; then
				write_old_line=0
				break
			elif [ "${token}" = "${hosts_localhost_update_hostname_old}" ] ; then
				write_old_line=0
				break
			fi
		done
		IFS=
		
		if [ "${write_old_line}" -eq 1 ] ; then
			echo -e  ${LINE} >> ${root_dir_path_guest}/etc/hosts 2>&1
		fi
	else
		echo -e ${LINE} >> ${root_dir_path_guest}/etc/hosts 2>&1
	fi
done < ${root_dir_path_guest}/etc/hosts.bak

# Set the host name to IP address of all nic.
if [ "${hosts_localhost_update_ipaddresses}" != "" ] ; then
	IFS=,
	for ipaddress in ${hosts_localhost_update_ipaddresses}
	do
		line="${ipaddress}\t"
		if [ "${hosts_localhost_update_domainname}" = "" ] ; then
			line=${line}${hosts_localhost_update_hostname}
		else
			line=${line}${hosts_localhost_update_hostname}"."${hosts_localhost_update_domainname}" "${hosts_localhost_update_hostname}
		fi
		echo -e ${line} >> ${root_dir_path_guest}/etc/hosts 2>&1
	done
fi

# Detete /etc/hosts.bak
rm -f  ${root_dir_path_guest}/etc/hosts.bak
IFS=${default_IFS}

return 0
}


# PRE CHECK

if [ `$ID -u` -ne 0 ] ; then
	$ECHO "ERROR0001: need to be root user" 1>&2
	exit 1
fi

# MAIN

$ECHO "INFO: Red Hat Enterprise Linux 6 paramset started `$DATE`"

# GET ABSOLUTE DIRECTORY

SCRIPT_DIR=`$DIRNAME $0`
pushd $SCRIPT_DIR 1>/dev/null
SCRIPT_DIR=`$PPWD`
pushd ../parampkg 1>/dev/null
PARAM_DIR=`$PPWD`
popd 1>/dev/null
popd 1>/dev/null

# GET SETUP PARAMETERS

if ! source $SCRIPT_DIR/setenv.sh ; then
	$ECHO "ERROR0002: setenv.sh exec failed" 1>&2
	exit 1
fi

# COPY PARAMETER FILE

if [ "$sysctl_conf" = true ] ; then
	$ECHO "IFNO: set sysctl.conf"
	$CP -p /etc/sysctl.conf /etc/sysctl.conf.cfmgbkup
	if ! $CP $PARAM_DIR/sysctl.conf /etc/sysctl.conf ; then
		$ECHO "ERROR0003: set sysctl.conf failed" 1>&2
		RET=1
	fi
fi

if [ "$grub_conf" = true ] ; then
	$ECHO "INFO: set grub.conf"
	$CP -p /etc/grub.conf /etc/grub.conf.cfmgbkup
	if ! $CP $PARAM_DIR/grub.conf /etc/grub.conf ; then
		$ECHO "ERROR0003: set grub.conf failed" 1>&2
		RET=1
	fi
fi

if [ "$limits_conf" = true ] ; then
	$ECHO "INFO: set limits.conf"
	$CP -p /etc/security/limits.conf /etc/security/limits.conf.cfmgbkup
	if ! $CP $PARAM_DIR/limits.conf /etc/security/limits.conf ; then
		$ECHO "ERROR0003: set limits.conf failed" 1>&2
		RET=1
	fi
fi

if [ "$rsyslog_conf" = true ] ; then
	$ECHO "INFO: set rsyslog.conf"
	$CP -p /etc/rsyslog.conf /etc/rsyslog.conf.cfmgbkup
	if ! $CP $PARAM_DIR/rsyslog.conf /etc/rsyslog.conf ; then
		$ECHO "ERROR0003: set rsyslog.conf failed" 1>&2
		RET=1
	fi
fi

if [ "$selinux" = true ] ; then
	$ECHO "INFO: set selinux"
	$CP -p /etc/selinux/config /etc/selinux/config.cfmgbkup
	if ! $CP $PARAM_DIR/config /etc/selinux/config ; then
		$ECHO "ERROR0003: set selinux failed" 1>&2
		RET=1
	fi
fi

if [ "$fstab" = true ] ; then
	$ECHO "INFO: set fstab"
	$CP -p /etc/fstab /etc/fstab.cfmgbkup
	if ! $CP $PARAM_DIR/fstab /etc/fstab ; then
		$ECHO "ERROR0003: set fstab failed" 1>&2
		RET=1
	fi
fi

if [ "$hosts" = true ] ; then
	$ECHO "INFO: set hosts"
	$CP -p /etc/hosts /etc/hosts.cfmgbkup
	if ! $CP $PARAM_DIR/hosts /etc/hosts ; then
		$ECHO "ERROR0003: set hosts failed" 1>&2
		RET=1
	fi
fi

if [ "$ntpd" = true ] ; then
	$ECHO "INFO: set ntpd"
	$CP -p /etc/sysconfig/ntpd /etc/sysconfig/ntpd.cfmgbkup
	if ! $CP $PARAM_DIR/ntpd /etc/sysconfig/ntpd ; then
		$ECHO "ERROR0003: set ntpd failed" 1>&2
		RET=1
	fi
fi

if [ "$ntpdate" = true ] ; then
	$ECHO "INFO: set ntpdate"
	$CP -p /etc/sysconfig/ntpdate /etc/sysconfig/ntpdate.cfmgbkup
	if ! $CP $PARAM_DIR/ntpdate /etc/sysconfig/ntpdate ; then
		$ECHO "ERROR0003: set ntpdate failed" 1>&2
		RET=1
	fi
fi

if [ "$snmpd_conf" = true ] ; then
	$ECHO "INFO: set snmpd.conf"
	$CP -p /etc/snmp/snmpd.conf /etc/snmp/snmpd.conf.cfmgbkup
	if ! $CP $PARAM_DIR/snmpd.conf /etc/snmp/snmpd.conf ; then
		$ECHO "ERROR0003: set snmpd.conf failed" 1>&2
		RET=1
	fi
fi

if [ "$services" = true ] ; then
	$ECHO "INFO: set services"
	$CP -p /etc/services /etc/services.cfmgbkup
	if ! $CP $PARAM_DIR/services /etc/services ; then
		$ECHO "ERROR0003: set services failed" 1>&2
		RET=1
	fi
fi

if [ "$profile" = true ] ; then
	$ECHO "INFO: set profile"
	$CP -p /etc/profile /etc/profile.cfmgbkup
	if ! $CP $PARAM_DIR/profile /etc/profile ; then
		$ECHO "ERROR0003: set profile failed" 1>&2
		RET=1
	fi
fi

# EDIT PARAMETER

if [ "${hosts_localhost_update_hostname}" != "" ] ||
   [ "${hosts_localhost_update_hostname_old}" != "" ] ||
   [ "${hosts_localhost_update_domainname}" != "" ] ||
   [ "${hosts_localhost_update_domainname_old}" != "" ] ||
   [ "${hosts_localhost_update_ipaddresses}" != "" ] ; then
	if [ "${hosts_localhost_update_hostname}" != "" ] &&
	   [ "${hosts_localhost_update_hostname_old}" != "" ] ; then
		
		method_update_localhost_of_hosts
		if [ $? -ne 0 ]; then
			RET=1
		fi
	else
		$ECHO "ERROR0004: set hosts localhost update failed" 1>&2
		RET=1
	fi
fi

$ECHO "INFO: Red Hat Enterprise Linux 6 paramset ended `$DATE`"
exit $RET

